summaryrefslogtreecommitdiff
path: root/src/lib/video_decoder.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2013-07-22 16:23:23 +0100
committerCarl Hetherington <cth@carlh.net>2013-07-22 16:23:23 +0100
commit8349f0c97d98c0b7550ff4c76ad25f8f06270d6a (patch)
treebf441e13142b2810ac4e46cf94d4204ec4e037d5 /src/lib/video_decoder.h
parent75712cfaf2a8ec8904d7d9552c542a2245bbbc17 (diff)
Basics of front-end 3D (as far as viewer, at least).
Diffstat (limited to 'src/lib/video_decoder.h')
-rw-r--r--src/lib/video_decoder.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/lib/video_decoder.h b/src/lib/video_decoder.h
index 26a11c805..142320a04 100644
--- a/src/lib/video_decoder.h
+++ b/src/lib/video_decoder.h
@@ -32,7 +32,7 @@ class Image;
class VideoDecoder : public virtual Decoder
{
public:
- VideoDecoder (boost::shared_ptr<const Film>);
+ VideoDecoder (boost::shared_ptr<const Film>, boost::shared_ptr<const VideoContent>);
/** Seek so that the next pass() will yield (approximately) the requested frame.
* Pass accurate = true to try harder to get close to the request.
@@ -41,14 +41,16 @@ public:
/** Emitted when a video frame is ready.
* First parameter is the video image.
* Second parameter is true if the image is the same as the last one that was emitted.
* Third parameter is the frame within our source.
*/
- boost::signals2::signal<void (boost::shared_ptr<const Image>, bool, VideoContent::Frame)> Video;
+ boost::signals2::signal<void (boost::shared_ptr<const Image>, Eyes, bool, VideoContent::Frame)> Video;
protected:
void video (boost::shared_ptr<const Image>, bool, VideoContent::Frame);
+ boost::shared_ptr<const VideoContent> _video_content;
VideoContent::Frame _video_position;
};
@@ -41,14 +41,16 @@ public:
/** Emitted when a video frame is ready.
* First parameter is the video image.
- * Second parameter is true if the image is the same as the last one that was emitted.
- * Third parameter is the frame within our source.
+ * Second parameter is the eye(s) which should see this image.
+ * Third parameter is true if the image is the same as the last one that was emitted for this Eyes value.
+ * Fourth parameter is the frame within our source.
*/